from ._clients import AniList, AsyncAniList
from ._enums import (
    CharacterRole,
    ExternalLinkType,
    MediaFormat,
    MediaRankType,
    MediaRelation,
    MediaSeason,
    MediaSource,
    MediaStatus,
    MediaType,
)
from ._exceptions import (
    CloseError,
    ConnectError,
    ConnectTimeout,
    CookieConflict,
    DecodingError,
    HTTPError,
    HTTPStatusError,
    InvalidURL,
    LocalProtocolError,
    NetworkError,
    PoolTimeout,
    ProtocolError,
    ProxyError,
    ReadError,
    ReadTimeout,
    RemoteProtocolError,
    RequestError,
    RequestNotRead,
    ResponseNotRead,
    StreamClosed,
    StreamConsumed,
    StreamError,
    TimeoutException,
    TooManyRedirects,
    UnsupportedProtocol,
    ValidationError,
    WriteError,
    WriteTimeout,
)
from ._models import (
    AiringSchedule,
    Character,
    CharacterImage,
    CharacterName,
    FuzzyDate,
    Media,
    MediaCoverImage,
    MediaDescription,
    MediaExternalLink,
    MediaRank,
    MediaStreamingEpisode,
    MediaTag,
    MediaTitle,
    MediaTrailer,
    Relation,
    Staff,
    StaffImage,
    StaffName,
    Studio,
)
from ._types import AniListID, AniListTitle, AniListYear, Color, CountryCode, HttpUrl, YearsActive
from ._version import VersionInfo, _get_version

__version__ = _get_version()
__version_tuple__ = VersionInfo(*map(int, __version__.split(".")))

__all__ = [
    # Clients
    "AsyncAniList",
    "AniList",
    # Enums
    "CharacterRole",
    "ExternalLinkType",
    "MediaFormat",
    "MediaRankType",
    "MediaRelation",
    "MediaSeason",
    "MediaSource",
    "MediaStatus",
    "MediaType",
    # Types
    "AniListID",
    "AniListTitle",
    "AniListYear",
    "Color",
    "CountryCode",
    "HttpUrl",
    "YearsActive",
    # Models
    "AiringSchedule",
    "Character",
    "CharacterImage",
    "CharacterName",
    "FuzzyDate",
    "Media",
    "MediaCoverImage",
    "MediaDescription",
    "MediaExternalLink",
    "MediaRank",
    "MediaStreamingEpisode",
    "MediaTag",
    "MediaTitle",
    "MediaTrailer",
    "Relation",
    "Staff",
    "StaffImage",
    "StaffName",
    "Studio",
    # Exceptions
    "CloseError",
    "ConnectError",
    "ConnectTimeout",
    "CookieConflict",
    "DecodingError",
    "HTTPError",
    "HTTPStatusError",
    "InvalidURL",
    "LocalProtocolError",
    "NetworkError",
    "PoolTimeout",
    "ProtocolError",
    "ProxyError",
    "ReadError",
    "ReadTimeout",
    "RemoteProtocolError",
    "RequestError",
    "RequestNotRead",
    "ResponseNotRead",
    "StreamClosed",
    "StreamConsumed",
    "StreamError",
    "TimeoutException",
    "TooManyRedirects",
    "UnsupportedProtocol",
    "WriteError",
    "WriteTimeout",
    "ValidationError",
]
